﻿using System;
using Microsoft.SharePoint;
using Microsoft.SharePoint.Utilities;
using System.Text;

namespace RH.UploadAndInsertField
{
    class Helper
    {
        private const string ResFile = "RHUploadAndInsertField";

        public static string GetResource(string resKey)
        {
            // get language from web regionalsettings
            uint language = SPContext.Current.Web.RegionalSettings.LocaleId;
            return GetResource(resKey, language);
        }

        public static string GetResource(string resKey, uint language)
        {
            return SPUtility.GetLocalizedString("$Resources:" + resKey, ResFile, language);
        }

        /// <summary>
        /// get javascript "getTagFromIdentifierAndTitle"
        /// </summary>
        /// <returns></returns>
        internal static string JavaScriptGetTagFromIdentifierAndTitle()
        {
            var js = new StringBuilder("function getTagFromIdentifierAndTitle(tagName, identifier, title)\r\n");
            js.Append("{\r\n");
            js.Append("    var len = identifier.length;\r\n");
            js.Append("    var tags = document.getElementsByTagName(tagName);\r\n");
            js.Append("    for (var i=0; i < tags.length; i++)\r\n");
            js.Append("    {\r\n");
            js.Append("        var tempString = tags[i].id;\r\n");
            js.Append("        if (tags[i].title == title && (identifier == \"\" || tempString.indexOf(identifier) == tempString.length - len))\r\n");
            js.Append("        {\r\n");
            js.Append("            return tags[i];\r\n");
            js.Append("        }\r\n");
            js.Append("    }\r\n");
            js.Append("    return null;\r\n");
            js.Append("}\r\n");

            js.Append("String.prototype.contains = function(t) { return this.indexOf(t) >= 0 ? true : false }\r\n");

            return js.ToString();
        }

        /// <summary>
        /// write to the ULS Log (TraceSeverity = Exception)
        /// </summary>
        /// <param name="text"></param>
        internal static void WriteUlsError(string text)
        {
            try
            {
                TraceProvider.RegisterTraceProvider();
                TraceProvider.WriteTrace(0, TraceProvider.TraceSeverity.Exception, Guid.Empty, "RH.UploadAndInsertField.dll", "RH.UploadAndInsertField", "General", text);
                TraceProvider.UnregisterTraceProvider();
            }
            catch (Exception)
            {
            }
        }

        /// <summary>
        /// write to the ULS Log (TraceSeverity = Verbose)
        /// </summary>
        /// <param name="text"></param>
        internal static void WriteUlsVerbose(string text)
        {
            try
            {
                TraceProvider.RegisterTraceProvider();
                TraceProvider.WriteTrace(0, TraceProvider.TraceSeverity.Verbose, Guid.Empty, "RH.UploadAndInsertField.dll", "RH.UploadAndInsertField", "General", text);
                TraceProvider.UnregisterTraceProvider();
            }
            catch (Exception)
            {
            }
        }
    }
}
