﻿using System;
using System.Data;

namespace RH.Update
{
    public class Updates
    {
        private readonly string _Assembly;
        private readonly string _FeedUrl;
        private string _ErrorText;

        /// <summary>
        /// create updates class with an assemblyname
        /// </summary>
        /// <param name="assembly"></param>
        public Updates(string assembly)
        {
            _Assembly = assembly;
            _FeedUrl = "http://www.hezser.de/_layouts/listfeed.aspx?List=%7BBD1D3115%2DF71B%2D4A5E%2D8A42%2DF8CEB00C9869%7D";
        }

        public Updates(string assembly, string feedUrl)
        {
            _Assembly = assembly;
            _FeedUrl = feedUrl;
        }

        /// <summary>
        /// find lates version from rss feed
        /// </summary>
        /// <returns></returns>
        public LatestVersion GetLatestVersion()
        {
            try
            {
                var ds = new DataSet();
                ds.ReadXml(_FeedUrl, XmlReadMode.Auto);

                DataTable dt = ds.Tables["item"];
                foreach (DataRow row in dt.Rows)
                {
                    if (Convert.ToString(row["title"]) != _Assembly) continue;

                    // we found our assembly
                    string description = Convert.ToString(row["description"]);
                    DateTime publishDate = Convert.ToDateTime(row["pubDate"]);

                    return new LatestVersion(description, publishDate, _ErrorText);
                }
                return new LatestVersion("No Versioninformation found.");
            }
            catch (Exception ex)
            {
                return new LatestVersion(ex.Message);
            }
        }
    }
}
